# scattermind

Scattermind is a decentralized and distributed horizontally scalable model
execution framework. Worried your model won't fit in memory? Scattermind
splits the model into small independently executable sub-models to accomodate
even small machines (*).

(*) Currently only available through plugins. Once the plugins have matured
they will be included in the main distribution.

An open source usage exapmle can be seen at https://github.com/UNDP-Accelerator-Labs/nlpapi
